==> laldetchar-0.3.3.tar.xz: laldetchar-0.3.3/src/LALDetCharVCSInfoHeader.h <==
/*
 * LALDetCharVCSInfo.h - LALDetChar VCS Information Header
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or (at
 * your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with with program; see the file COPYING. If not, write to the
 * Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
 * MA 02111-1307 USA
 *
 * Copyright (C) 2009-2013 Adam Mercer
 * Copyright (C) 2014 Karl Wette
 */

/** \cond DONT_DOXYGEN */

#ifndef _LALDETCHARVCSINFOHEADER_H
#define _LALDETCHARVCSINFOHEADER_H

#include <lal/LALVCSInfoType.h>
#include <lal/LALDetCharVCSInfo.h>
#include <lal/LALDetCharConfig.h>

#ifdef __cplusplus
extern "C" {
#endif

/* VCS information defines */
#define LALDETCHAR_NAME "LALDetChar"
#define LALDETCHAR_VCS_ID "ba201afc668db586873cfb309433dcd47a1ded33"
#define LALDETCHAR_VCS_DATE "2016-06-26 21:26:32 +0000"
#define LALDETCHAR_VCS_BRANCH "None"
#define LALDETCHAR_VCS_TAG "laldetchar-v0.3.3"
#define LALDETCHAR_VCS_AUTHOR "Adam Mercer <adam.mercer@ligo.org>"
#define LALDETCHAR_VCS_COMMITTER "Adam Mercer <ramercer@gmail.com>"
#define LALDETCHAR_VCS_STATUS "CLEAN: All modifications committed"

/* Identable VCS information defines */
#define LALDETCHAR_VCS_IDENT_ID "$" "LALDetCharId: ba201afc668db586873cfb309433dcd47a1ded33 " "$"
#define LALDETCHAR_VCS_IDENT_DATE "$" "LALDetCharDate: 2016-06-26 21:26:32 +0000 " "$"
#define LALDETCHAR_VCS_IDENT_BRANCH "$" "LALDetCharBranch: None " "$"
#define LALDETCHAR_VCS_IDENT_TAG "$" "LALDetCharTag: laldetchar-v0.3.3 " "$"
#define LALDETCHAR_VCS_IDENT_AUTHOR "$" "LALDetCharAuthor: Adam Mercer <adam.mercer@ligo.org> " "$"
#define LALDETCHAR_VCS_IDENT_COMMITTER "$" "LALDetCharCommitter: Adam Mercer <ramercer@gmail.com> " "$"
#define LALDETCHAR_VCS_IDENT_STATUS "$" "LALDetCharStatus: CLEAN: All modifications committed " "$"

/* Header VCS information structure */
static const LALVCSInfo lalDetCharVCSInfoHeader = { \
  LALDETCHAR_NAME, \
  LALDETCHAR_VERSION, \
  LALDETCHAR_VCS_ID, \
  LALDETCHAR_VCS_DATE, \
  LALDETCHAR_VCS_BRANCH, \
  LALDETCHAR_VCS_TAG, \
  LALDETCHAR_VCS_AUTHOR, \
  LALDETCHAR_VCS_COMMITTER, \
  LALDETCHAR_VCS_STATUS \
};

#ifdef __cplusplus
}
#endif

#endif /* _LALDETCHARVCSINFOHEADER_H */

/** \endcond */

/*
 * vim: tw=0 ts=2 et
 */

==> laldetchar-0.3.4.tar.xz: laldetchar-0.3.4/src/LALDetCharVCSInfoHeader.h <==
/*
 * LALDetCharVCSInfo.h - LALDetChar VCS Information Header
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or (at
 * your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with with program; see the file COPYING. If not, write to the
 * Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
 * MA 02111-1307 USA
 *
 * Copyright (C) 2009-2013 Adam Mercer
 * Copyright (C) 2014 Karl Wette
 */

/** \cond DONT_DOXYGEN */

#ifndef _LALDETCHARVCSINFOHEADER_H
#define _LALDETCHARVCSINFOHEADER_H

#include <lal/LALVCSInfoType.h>
#include <lal/LALDetCharVCSInfo.h>
#include <lal/LALDetCharConfig.h>

#ifdef __cplusplus
extern "C" {
#endif

/* VCS information defines */
#define LALDETCHAR_NAME "LALDetChar"
#define LALDETCHAR_VCS_ID "b6ccf6e5998509725e3676332a7bb352509de687"
#define LALDETCHAR_VCS_DATE "2016-10-10 17:31:35 +0000"
#define LALDETCHAR_VCS_BRANCH "None"
#define LALDETCHAR_VCS_TAG "laldetchar-v0.3.4"
#define LALDETCHAR_VCS_AUTHOR "Adam Mercer <adam.mercer@ligo.org>"
#define LALDETCHAR_VCS_COMMITTER "Adam Mercer <adam.mercer@ligo.org>"
#define LALDETCHAR_VCS_STATUS "CLEAN: All modifications committed"

/* Identable VCS information defines */
#define LALDETCHAR_VCS_IDENT_ID "$" "LALDetCharId: b6ccf6e5998509725e3676332a7bb352509de687 " "$"
#define LALDETCHAR_VCS_IDENT_DATE "$" "LALDetCharDate: 2016-10-10 17:31:35 +0000 " "$"
#define LALDETCHAR_VCS_IDENT_BRANCH "$" "LALDetCharBranch: None " "$"
#define LALDETCHAR_VCS_IDENT_TAG "$" "LALDetCharTag: laldetchar-v0.3.4 " "$"
#define LALDETCHAR_VCS_IDENT_AUTHOR "$" "LALDetCharAuthor: Adam Mercer <adam.mercer@ligo.org> " "$"
#define LALDETCHAR_VCS_IDENT_COMMITTER "$" "LALDetCharCommitter: Adam Mercer <adam.mercer@ligo.org> " "$"
#define LALDETCHAR_VCS_IDENT_STATUS "$" "LALDetCharStatus: CLEAN: All modifications committed " "$"

/* Header VCS information structure */
static const LALVCSInfo lalDetCharVCSInfoHeader = { \
  LALDETCHAR_NAME, \
  LALDETCHAR_VERSION, \
  LALDETCHAR_VCS_ID, \
  LALDETCHAR_VCS_DATE, \
  LALDETCHAR_VCS_BRANCH, \
  LALDETCHAR_VCS_TAG, \
  LALDETCHAR_VCS_AUTHOR, \
  LALDETCHAR_VCS_COMMITTER, \
  LALDETCHAR_VCS_STATUS \
};

#ifdef __cplusplus
}
#endif

#endif /* _LALDETCHARVCSINFOHEADER_H */

/** \endcond */

/*
 * vim: tw=0 ts=2 et
 */
